==> smb4k_0.6.5.orig.tar.gz: smb4k-0.6.5/smb4k/core/smb4kglobal.h <==
/***************************************************************************
                          smb4kglobal  -  description
                             -------------------
    begin                : Sa Apr 2 2005
    copyright            : (C) 2005 by Alexander Reinholdt
    email                : dustpuppy@mail.berlios.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SMB4KGLOBAL_H
#define SMB4KGLOBAL_H

#include <qstring.h>
#include <qmap.h>
#include <qtimer.h>

#include <kconfig.h>

#include "smb4kpasswordhandler.h"


/**
 * This is the global namespace for the core classes of Smb4K.
 *
 * @author    Alexander Reinholdt <dustpuppy@mail.berlios.de>
 */

namespace Smb4K_Global
{
  /**
   * This function returns the "global" options for smbclient, i.e. if Kerberos
   * should be used, etc.
   *
   * @returns           A string with the "global" options for nmblookup
   */
  const QString getSmbclientOptions();

  /**
   * This function returns the "global" options for nmblookup, i.e. the domain
   * the client is in, if Kerberos should be used, etc.
   *
   * @returns           A string with the "global" options for nmblookup
   */
  const QString getNmblookupOptions();

  /**
   * Returns the map of global smb.conf options. You can reach the value
   * of each option by providing the lowercase option name as key, if it
   * was defined in the global section of the smb.conf.
   *
   * @returns           A map of the [global] section of the smb.conf
   */
  const QMap<QString, QString> readGlobalSMBOptions();

  /**
   * This function returns the WINS server the system is using.
   *
   * @returns           The name or IP of the WINS server
   */
  const QString getWINSServer();

  /**
   * This function returns the Kernel version string. Vendor specific extension
   * will be ignored. That means the string will look like this '2.6.10' rather
   * than '2.6.10-blabla'. This function is mainly provided for convenience.
   *
   * @returns           The version string of the kernel
   */
  const QString getKernelVersion();

  /**
   * This function returns the system name. It is mainly provided for
   * convenience.
   *
   * @returns           The name of the system
   */
  const QString getSystemName();

  /**
   * This function returns the UMASK as integer. It is provided
   * for convenience.
   *
   * @returns           The UMASK as integer
   */
  int getUMASK();

  /**
   * This function returns the "global" options for the net command.
   * You'll have to provide the command that you want to use to get the
   * right options back.
   *
   * @param command     The command that should be used. It has to be one
   *                    of the following: "share", "share_no_protocol" (same as "share"
   *                    but without protocol), "server domain", "lookup host [HOST]".
   *                    See also the manual page of the net command for more info.
   *
   * @returns           The global 'net' command options
   */
  const QString getNetOptions( const QString &command );

  /**
   * This is the global KConfig object for Smb4K. It points to the configuration
   * stored in $HOME/.kde/share/config/smb4krc.
   *
   * @returns           A pointer to the global KConfig object.
   */
  KConfig *config();

  /**
   * This returns the pointer to the global timer for the application.
   * WARNING: Du *NOT* stop this timer anywhere in the program or all
   * actions that need a timer are stopped all over the application!
   *
   * @returns           A pointer to the global timer.
   */
  QTimer *timer();

  /**
   * This function returns the interval of the timer.
   *
   * @returns           The interval of the timer in msec.
   */
  const int timerInterval();
};

#endif

==> smb4k_0.7.5.orig.tar.gz: smb4k-0.7.5/smb4k/core/smb4kglobal.h <==
/***************************************************************************
    smb4kglobal  -  This is the global namespace for Smb4K.
                             -------------------
    begin                : Sa Apr 2 2005
    copyright            : (C) 2005 by Alexander Reinholdt
    email                : dustpuppy@mail.berlios.de
 ***************************************************************************/

/***************************************************************************
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,   *
 *   MA  02111-1307 USA                                                    *
 ***************************************************************************/

#ifndef SMB4KGLOBAL_H
#define SMB4KGLOBAL_H

#include <qstring.h>
#include <qmap.h>
#include <qtimer.h>

#include <kconfig.h>

#include "smb4kpasswordhandler.h"


/**
 * This is the global namespace for the core classes of Smb4K.
 *
 * @author    Alexander Reinholdt <dustpuppy@mail.berlios.de>
 */

namespace Smb4KGlobal
{
  /**
   * This function returns the "global" options for smbclient, i.e. if Kerberos
   * should be used, etc.
   *
   * @returns           A string with the "global" options for nmblookup
   */
  const QString smbclientOptions();

  /**
   * This function returns the "global" options for nmblookup, i.e. the domain
   * the client is in, if Kerberos should be used, etc.
   *
   * @returns           A string with the "global" options for nmblookup
   */
  const QString nmblookupOptions();

  /**
   * Returns the map of global smb.conf options. You can reach the value
   * of each option by providing the lowercase option name as key, if it
   * was defined in the global section of the smb.conf.
   *
   * @returns           A map of the [global] section of the smb.conf
   */
  const QMap<QString, QString> globalSMBOptions();

  /**
   * This function returns the WINS server the system is using.
   *
   * @returns           The name or IP of the WINS server
   */
  const QString winsServer();

  /**
   * This function returns the Kernel version string. Vendor specific extension
   * will be ignored. That means the string will look like this '2.6.10' rather
   * than '2.6.10-blabla'. This function is mainly provided for convenience.
   *
   * @returns           The version string of the kernel
   */
  const QString kernelVersion();

  /**
   * This function returns the system name. It is mainly provided for
   * convenience.
   *
   * @returns           The name of the system
   */
  const QString systemName();

  /**
   * This function returns the UMASK as integer. It is provided
   * for convenience.
   *
   * @returns           The UMASK as integer
   */
  int getUMASK();

  /**
   * This function returns the "global" options for the net command.
   * You'll have to provide the command that you want to use to get the
   * right options back.
   *
   * @param command     The command that should be used. It has to be one
   *                    of the following:
   *                    "share",
   *                    "share_no_protocol" (same as "share" but without protocol)
   *                    "server domain"
   *                    "lookup host [HOST]",
   *                    "lookup master [DOMAIN]",
   *                    "domain".
   *                    See also the manual page of the net command for more info.
   *
   * @returns           The global 'net' command options
   */
  const QString netOptions( const QString &command );

  /**
   * This is the global KConfig object for Smb4K. It points to the configuration
   * stored in $HOME/.kde/share/config/smb4krc (and *NOT* to kapp->config()).
   *
   * @returns           A pointer to the global KConfig object.
   */
  KConfig *config();

  /**
   * This returns the pointer to the global timer for the application.
   * WARNING: Du *NOT* stop this timer anywhere in the program or all
   * actions that need a timer are stopped all over the application!
   *
   * @returns           A pointer to the global timer.
   */
  QTimer *timer();

  /**
   * This function returns the interval of the timer.
   *
   * @returns           The interval of the timer in msec.
   */
  const int timerInterval();

  /**
   * This function will open a dialog where the user has to define a
   * user name to access a 'homes' share. Besides returning this name,
   * this function will also store the name in the configuration file.
   *
   * @param host        The host where the homes share is located
   *
   * @returns           A user name
   */
  const QString specifyUser( const QString &host );

  /**
   * This function is called if an error in one of the core classes
   * occurred. The error codes are defined in the smb4kdefs.h file and the error
   * message depends on the error that occurred. Mostly, it is the shell output
   * of a process. The error codes determine the text and form of the error dialog
   * that'll be shown.
   *
   * @param code        The error code
   *
   * @param message     The error message. May be empty.
   */
  void showCoreError( int code, const QString &message = QString::null );
};

#endif
